Chemical bonding without orbitals - ScienceDirect
Description: This work presents an implementation of the original orbital-free Hohenberg-Kohn density functional theory in a form that is able to predict chemical …

Skip to main content Skip to article

- Access through your institution
- Purchase PDF

Search ScienceDirect

## Computational and Theoretical Chemistry

Volume 1144, 15 November 2018, Pages 50-55

# Chemical bonding without orbitals

Author links open overlay panel
https://doi.org/10.1016/j.comptc.2018.10.004
Get rights and content

## Abstract

This work presents an implementation of the original orbital-free Hohenberg-Kohn density functional theory in a form that is able to predict chemical bonding in molecules. The method is completely parameter-free and does not require analytical functional approximations. Instead, the proposed method is based on the idea that atoms are meaningful pieces of a molecule and thus, a promolecule, build from frozen spherical atomic entities, serves as a suitable model for the latter. This idea is imposed on the physical equations, originating from density functional theory converted into a bifunctional formalism.

The viewpoint proposed in this study offers a new strategic way of subsequent approximation levels in orbital-free density functional theory. In this work the zeroth order approximation is shown to predict chemical bonding in molecules, providing a concept of the chemical bond without involving orbitals.

## Graphical abstract

1. Download : Download high-res image (50KB)
2. Download : Download full-size image

## Introduction

The chemical bond [1], [2], [3], [4] is a fundamental concept in chemistry and related sciences. Taking a very simplistic standpoint, the chemical bond somehow serves as glue, binding together the partaking atoms [5], [6]. One part of chemistry is to define and quantify chemical bonding in order to predict molecular stability and how the system will undergo possible changes induced by the environment. Unfortunately, the definition of that chemical bonding is ambiguous. This is due to the fact that atoms in molecules are no physical entities. From a puristic standpoint, the molecule is defined once the number of electrons and the nuclear positions are given. By solving the quantum mechanical equations [7], [5], the statistical distribution of the electrons in the field of the nuclei is determined. In that spirit, the molecule only consists as a whole, namely of all nuclei and all electrons, whereby the latter are usually (but not necessarily) described in terms of orbitals. The equations describe all orbitals at once and their solutions extend over the whole space. This form of wavefunction based quantum mechanics is said to be non-local [7], meaning that changes induced at one position in space might cause noticeable effects far away from the initial position. Such a non-local form of quantum mechanics is not suited for an atomic fragment approach, where those fragments are thought as being subjected to a physical interaction.

Indeed a local from of quantum theory is needed, further allowing for a meaningful separation into atomic fragments. This local form of quantum theory is called density-functional theory (DFT) [8], [9]. In the Hohenberg-Kohn variant[10], the system is described by the electron density itself, rather than by orbitals. This theory is guided by a local causality principle [11], [12], [13], [14], [15], [16], [17], [18] (effective interactions decrease with increasing distance) and, as will be shown in this work, allows for a meaningful separation into atomic fragments, while keeping the initial physical equations unaltered. Although the original ideas of Hohenberg and Kohn dates back more than fifty years, a widespread use of orbital-free DFT has been hampered by the lack of sufficiently accurate functional approximations for the kinetic energy [19]. Whereas considerable progress has been made for one-dimensional systems [20], the treatment of molecular systems or solids requires appropriate three-dimensional functional approximations. First work was based on conventional gradient expansions [21], [22], [23], [24], [25], [26], [27], [28], [29], [30], [31], [32], whereas recent functional development is mainly focused on techniques based on the generalized-gradient-approximation motivated by conjoint arguments [33], [34] or the fulfillment of additional constraints [35], [36], [19]. Information-theory motivated functionals [37], [38], [39], functionals based on response theory [40], [41], and expansions in terms of moment densities [42] have been studied. Recently, a very promising approach based on the Liu-Parr power series expansion [43] has been suggested by Ludeña and coworkers [44], [45], including a detailed investigation concerning the ability of their ansatz to represent the atomic shell structure. Despite much efforts, it still remains difficult to design appropriate functional approximations, which yield properly structured electron densities from variational procedure [46]. This failure can be attributed to an insufficient incorporation of the Pauli exclusion principle [27], [8], [19] in the Pauli kinetic energy and the corresponding Pauli potential [47]. Both terms were intensively studied in the literature [48], [49], [50], [51], [52], [53], [54], [55], [56] as they represent the unknown part of the kinetic energy functional and the corresponding potential, respectively. As a consequence, there is up to now no reliably working orbital-free density functional implementation for the waste variety of chemical substances. There are a few noticeable exceptions treating variational orbital-free density functional approximations [57], [58], [59], [60], [61]. However, widespread applications covering all types of chemical substances without need of recursive adjustment of technical details are still out of reach.

This work offers a new strategy in orbital-free density functional theory based on the reformulation in terms of bifunctionals.

## Section snippets

## Formulation of the problem

In 1964 Hohenberg and Kohn (HK) rigorously founded density functional theory (DFT) [10]. In their seminal paper they proved the one-to-one correspondence between the energy E of the system and the external potential due to the nuclei v Z (first HK theorem) as well as the minimum principle of that energy functional E[ρ] (second HK theorem) for all electron densities ρ that are associated with some external potential. According to the first HK theorem, the electronic energy of a system E[ρ], given

## Reformulation in terms of bifunctionals

The conventional strategy in the design of energy functionals is to start with an ansatz for the energy in the form of an analytical expression that is an integral over a function f, which in some way contains the electron density (and possibly some other ingredients):F[ρ]=∫f(ρ(r→),…)d r→.From that functional, the potential, being the functional derivative, is obtained analytically, cf. Eq. (3). As mentioned, no ansatz for the kinetic energy has been found that is able to predict chemical

## The chemical bond in the atomic fragment approximation

From a chemist’s viewpoint it seems natural to interpret [71], [72], [73] large aggregates as being composed from atomic fragments [74], [75], [76], [77] that somehow hold together. In the following it is shown how to link such a viewpoint with the quantum mechanical equations based on the bifunctional formalism and the atomic fragment approach.

A so-called promolecule [78], [76] is the sum of (usually spherical) atoms centered at the positions of the nuclei for the actual molecule of interest.

## Discussion

This work presents an orbital-free implementation of the original Hohenberg-Kohn density functional theory, that is able to predict bonding in molecules. The proposed method is completely parameter-free and does not require analytical ansatzes for the energy functionals. Instead, it is based on the idea that atoms are meaningful pieces of a molecule and thus, a promolecule serves as a good model for the latter. This idea is imposed on the physical equations, originating from density functional

## Acknowledgments

The author wishes to thank Dr. M. Kohout for fruitful discussions and substantial encouragement over years. Prof. Dr. M. Ruck is greatly acknowledged for academic support and valuable hints on the manuscript. The Technische Universität Dresden is acknowledged for funding in terms of a Maria-Reiche fellowship.

## References (79)

- V. Karasiev et al.

  ### Frank discussion o the status of ground-state orbital-free DFT

  ### Adv. Quant. Chem.

  (2015)
- N.H. March

  ### The local potential determining the square root of the ground-state electron density of atoms and molecules from the Schrödinger equation

  ### Phys. Lett. A

  (1986)
- A. Nagy

  ### Alternative descriptors of Coulomb systems and their relationship to the kinetic energy

  ### Chem. Phys. Lett.

  (2008)
- V. Karasiev et al.

  ### Finite-temperature orbital-free DFT molecular dynamics: coupling profess and quantum espresso

  ### Comput. Phys. Commun.

  (2014)
- G.N. Lewis

  ### The atom and the molecule

  ### J. Am. Chem. Soc.

  (1916)
- W. Kossel

  ### Über Molekülbildung als Frage des Atombaus

  ### Ann. Phys.

  (1916)
- L. Pauling

  ### The nature of the chemical bond. IV. The energy of single bonds and the relative electronegativity of atoms

  ### J. Am. Chem. Soc.

  (1932)
- K. Ruedenberg

  ### The physical nature of the chemical bond

  ### Rev. Mod. Phys.

  (1962)
- W. Kutzelnigg

  ### Einführung in die Theoretische Chemie

  (2002)
- G. Frenking et al.

  ### The Chemical Bond: Fundamental Aspects of Chemical Bonding

  (2014)

- A. Szabo et al.

  ### Modern Quantum Chemistry – Introduction to Advanced Electronic Structure Theory

  (1996)
- R.M. Dreizler et al.

  ### Density Functional Theory

  (1990)
- R.G. Parr et al.

  ### Density-Functional Theory of Atoms and Molecules

  (1989)
- P. Hohenberg et al.

  ### Inhomogeous Electron Gas

  ### Phys. Rev. B

  (1964)
- W. Kohn et al.

  ### Locality principle in wave mechanics

  ### Proc. Natl. Acad. Sci. USA

  (1978)
- X.-P. Li et al.

  ### Density-matrix electronic structure method with linear system-size scaling

  ### Phys. Rev. B

  (1993)
- W. Kohn

  ### Density functional and density matrix method scaling linearly with the number of atoms

  ### Phys. Rev. Lett.

  (1996)
- R. Baer et al.

  ### Sparsity of the density matrix in Kohn-Sham density functional theory and an assessment of linear system-size scaling methods

  ### Phys. Rev. Lett.

  (1997)
- E. Prodan et al.

  ### Nearsightedness of electronic matter

  ### Proc. Natl. Acad. Sci.

  (2005)
- R.F.W. Bader

  ### Nearsightedness of electronic matter seen by a physicist and a chemist

  ### J. Phys. Chem. A

  (2008)
- C. Cárdenas et al.

  ### Chemical reactivity descriptors for ambiphilic reagents: dual descriptor, local hypersoftness, and electrostatic potential

  ### J. Phys. Chem. A

  (2009)
- S. Fias et al.

  ### Chemical transferability of functional groups follows from the nearsightedness of electronic matter

  ### Proc. Natl. Acad. Sci.

  (2017)
- A. Cangi et al.

  ### Leading corrections to local approximations

  ### Phys. Rev. B

  (2010)
- L.H. Thomas

  ### The calculation of atomic fields

  ### Proc. Cambridge Philos. Soc.

  (1927)
- E. Fermi

  ### Eine statistische Methode zur Bestimmung einiger Eigenschaften des Atoms und ihre Anwendung auf die Theorie des periodischen Systems der Elemente

  ### Z. Phys.

  (1928)
- C.F. von Weizsäcker

  ### Zur Theorie der Kernmassen

  ### Z. Phys.

  (1935)
- D.A. Kirzhnits

  ### Quantum corrections to the Thomas-Fermi equation

  ### Sov. Phys. JETP

  (1957)
- C.H. Hodges

  ### Quantum corrections to the Thomas-Fermi approximation – the Kirzhnits Method

  ### Can. J. Phys.

  (1973)
- D.R. Murphy

  ### Sixth-order term of the gradient expansion of the kinetic-energy density functional

  ### Phys. Rev. A

  (1981)
- W. Yang

  ### Gradient correction in Thomas-Fermi theory

  ### Phys. Rev. A

  (1986)
- W. Yang et al.

  ### Various functionals for the kinetic energy density of an atom or molecule

  ### Phys. Rev. A

  (1986)
- C.L. Lee et al.

  ### Density gradient expansion of the kinetic-energy functional for molecules

  ### Phys. Rev. A

  (1986)
- P.M. Kozlowski et al.

  ### A graph approach to the gradient expansion of density functionals

  ### Int. J. Quant. Chem.

  (1986)
- A.J. Thakkar

  ### Comparison of kinetic-energy density functionals

  ### Phys. Rev. A

  (1992)
- J.-D. Chai et al.

  ### Modified statistical treatment of kinetic energy in the thomas-fermi model

  ### J. Phys. Chem. B

  (2004)
- H. Lee et al.

  ### Conjoint gradient correction to the Hartree-Fock kinetic- and exchange-energy density functionals

  ### Phys. Rev. A

  (1991)
- F. Tran et al.

  ### Link between the kinetic- and exchange-energy functionals in the generalized gradient approximation

  ### Int. J. Quant. Chem.

  (2002)
- D. Lee et al.

  ### Condition on the Kohn-Sham kinetic energy and modern parametrization of the Thomas-Fermi density

  ### J. Chem. Phys.

  (2009)
- V. Karasiev et al.

  ### Progress on new approaches to old ideas: orbital-free density functionals

## Cited by (15)

- ### A study of the basis set dependence of the bifunctional expression of the non-interacting kinetic energy for atomic systems

  2019, Computational and Theoretical Chemistry
  Citation Excerpt :

  This approach requires appropriate density-based approximations for the kinetic energy. Recently, a parameter-free approximation based on a bifunctional expression was introduced [8,9]. In contrast to other known approaches in the literature targeting the energy functional directly [10–41], the proposed bifunctional approach is based on an approximation of the first functional derivative.

  The non-interacting kinetic energy is divided into the von Weizsäcker term and the Pauli kinetic energy. Whereas the von Weizsäcker energy is known in terms of the density, the Pauli kinetic energy is not. Consequently, its functional derivative can only be determined formally, at the solution point, from a given set of Kohn-Sham eigenfunctions. Since in a practical calculation the solution point is never reached exactly, the formal functional derivative is evaluated only in proximity of the solution point. Therefore, bifunctional expressions involving the corresponding potential are approximate. In this study the atoms from H - Xe are examined, showing that the energy deviation between the bifunctional expression and the orbital-based kinetic energy density is of a few hundred millihartrees for a quadruple basis set, while it can reach the order of a few hartrees when employing basis sets of less quality.

- ### Developing orbital-free quantum crystallography: The local potentials and associated partial charge densities

  2021, Acta Crystallographica Section B: Structural Science, Crystal Engineering and Materials

- ### Detailed analysis of deformation potentials with application in orbital-free density functional theory

  2021, Acta Crystallographica Section B: Structural Science, Crystal Engineering and Materials

- ### Orbital-Free Density Functional Theory: An Attractive Electronic Structure Method for Large-Scale First-Principles Simulations

  2023, Chemical Reviews

- ### Geometric potential of the exact electron factorization: Meaning, significance, and application

  2023, Physical Review Research

- ### On the geometric potential and the relationship between the exact electron factorization and density functional theory

  2021, arXiv

View all citing articles on Scopus
View full text
© 2018 Elsevier B.V. All rights reserved.

- ### Influence of image charge effect on the binding energy of hydrogen-like donor impurity in a near-surface quantum well under transverse electric field

  Physica E: Low-dimensional Systems and Nanostructures, Volume 106, 2019, pp. 1-4
  A.L. Vartanian, …, K.A. Vardanyan

- ### NFFT based Ewald summation for electrostatic systems with charges and dipoles

  Applied Numerical Mathematics, Volume 122, 2017, pp. 39-65
  Michael Hofmann, …, Michael Pippig

- ### Magnetostructural study of four-coordinated Co(II) complexes with mixed ligand surrounding

  Polyhedron, Volume 194, 2021, Article 114936
  Serghei Ostrovsky

- ### Nomograph method for predicting magnetoelectric coupling

  Journal of Magnetism and Magnetic Materials, Volume 412, 2016, pp. 1-6
  Mirza Bichurin, …, Ksenia Lavrentieva

- ### Luminescence | Overview

  Encyclopedia of Analytical Science, 2019, pp. 270-280
  Jacqui L. Adcock, …, Paul S. Francis

- ### Efficacy of ultrasonic treatment for dispersing nanoparticles: A correlation with microstructure

  Materials Today: Proceedings, Volume 45, Part 9, 2021, pp. 7845-7849
  K.T. Sunu Surendran, A. Gnanavelbabu

View article metrics